@@ -87,8 +87,10 @@ def _create_mode(ui, cfg):
     else:
         torrent.creation_date = datetime.datetime.now()
 
-    if cfg['max_piece_size'] and torrent.piece_size > cfg['max_piece_size']:
-        torrent.piece_size = cfg['max_piece_size']
+    if cfg['max_piece_size']:
+        torf.Torrent.piece_size_max = cfg['max_piece_size']
+        if torrent.piece_size > cfg['max_piece_size']:
+            torrent.piece_size = cfg['max_piece_size']
 
     ui.check_output_file_exists(_utils.get_torrent_filepath(torrent, cfg))
     ui.show_torrent(torrent)
